# Generated by Plain 0.15.0 on 2025-01-06 20:17

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("plainpageviews", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="pageview",
            name="referrer",
            field=models.URLField(blank=True, max_length=1024),
        ),
        migrations.AlterField(
            model_name="pageview",
            name="title",
            field=models.CharField(blank=True, max_length=512),
        ),
        migrations.AlterField(
            model_name="pageview",
            name="url",
            field=models.URLField(db_index=True, max_length=1024),
        ),
    ]
